-- Created by NuclearTonic
-- The use of this code requires the permission of the author.
-- Permission can be atained by contacting NuclearTonic at: TonicBars@gmail.com
--
-- RESPECT!

import "Turbine";
import "Turbine.UI";
import "Tonic.TonicBars.QuickslotList";
import "Tonic.Utils.Class";
import "Turbine.Gameplay";

Bar = class( Turbine.UI.Window );

function Bar:Constructor( barid, sManager, theBarType )
	Turbine.UI.Window.Constructor( self );

	self.id = barid;
	self.theSettingsManager = sManager;
	if ( theBarType == EXTENSIONBAR ) then
		self.isModal = false;
		self.faded = false;
	else
		self.isModal = true;
		self.faded = true;
	end
	
	local bSettings = self.theSettingsManager:GetBarSettings( self.id );
	self.dragged = false;
	self.qsCreated = false;
	self.isSelectedOnMainMenu = false;
	self.f12HideBar = false;
	
	self:SetMouseVisible( true );
	self:SetAllowDrop( true );
	self:SetPosition( bSettings.x, bSettings.y );
		
	if ( self.isModal == true ) then
		self.MouseEnter = function(sender,args)
			local barSettings = self.theSettingsManager:GetBarSettings( self.id );
			if ( maitre_d:Alive( self.id ) and barSettings.useFading == true ) then
				self.faded = false;
				self:Refresh();
			end
		end
		self.MouseLeave = function(sender,args)
			local barSettings = self.theSettingsManager:GetBarSettings( self.id );
			if ( maitre_d:Alive( self.id ) and barSettings.useFading == true ) then
				self.faded = true;
				self:Refresh();
			end
		end
		self.PositionChanged = function( sender, args )
			local settings = self.theSettingsManager:GetSettings();
			local barSettings = self.theSettingsManager:GetBarSettings( self.id );
			if ( maitre_d:Alive( self.id ) and settings.barMode ~= NORMAL_MODE ) then
				local x,y = self:GetPosition();
				if ( barSettings.x ~= x or barSettings.y ~= y ) then
					barSettings.x = x;
					barSettings.y = y;
					self.theSettingsManager:SetBarSettings( self.id, barSettings );
				end
				maitre_d:UpdateBarExtensions();
			end
		end

		self.MouseDown = function( sender, args )
			if ( maitre_d:Alive( self.id ) == true ) then
				local settings = self.theSettingsManager:GetSettings();
				if ( settings.barMode ~= NORMAL_MODE ) then
					if ( args.Button == Turbine.UI.MouseButton.Left ) then
						self.dragStartX = args.X;
						self.dragStartY = args.Y;
						self.dragging = true;
						self.dragged = false;
					end
				end
			end
		end

		self.MouseMove = function( sender, args )
			local left, top = self:GetPosition();
			local settings = self.theSettingsManager:GetSettings();
			if ( maitre_d:Alive( self.id ) and settings.barMode ~= NORMAL_MODE and self.dragging ) then
				self:SetPosition( left + ( args.X - self.dragStartX ), top + ( args.Y - self.dragStartY ) );
				self.dragged = true;
				maitre_d:UpdateBarExtensions();
			end
		end
		
		self.MouseUp = function( sender, args )
			if ( maitre_d:Alive( self.id ) == true and args.Button == Turbine.UI.MouseButton.Left ) then
				self.dragging = false;
			  
				if( self.dragged ) then
					local x, y = self:GetPosition();
					local validX = x;
					local validY = y;
					if( x < 0 ) then
						x = 0;
					end
			
					if( y < 0 ) then
						y = 0;
					end
					if( x + self:GetWidth() > Turbine.UI.Display.GetWidth() ) then
						x = Turbine.UI.Display.GetWidth() - self:GetWidth();
					end
					if( y + self:GetHeight() > Turbine.UI.Display.GetHeight() ) then
						y = Turbine.UI.Display.GetHeight() - self:GetHeight();
					end
			
					self:SetPosition( x, y );
				end
			end
		end
	end

	self:Create();

	local bSettings = self.theSettingsManager:GetBarSettings( self.id );
	self.quickslotList.loading = true;
	self.theSettingsManager:LoadQuickslots( bSettings, self.quickslotList.quickslots );
	self.quickslotList.loading = false;
end

function Bar:Create()
	local barSettings = self.theSettingsManager:GetBarSettings( self.id );
	
	self.quickslotList = QuickslotList( self.id, self.theSettingsManager );
	self.quickslotList:SetParent( self );
	self.quickslotList:SetMaxItemsPerLine( barSettings.quickslotColumns );
	self.quickslotList:SetPosition(0, 0 );

	self.qsCreated = true;

	self:Refresh();
end

function Bar:ClearQuickslots()
	self.quickslotList:ClearQuickslots()
end

function Bar:Refresh()
	local settings = self.theSettingsManager:GetSettings();
	local barSettings = self.theSettingsManager:GetBarSettings( self.id );
	if ( settings.barMode ~= NORMAL_MODE ) then
		if (self.id == settings.selectedBar) then
			self:SetOpacity( 0.5 );
			self:SetBackColor( Turbine.UI.Color(1,0,1,0) );
		else
			if ( (barSettings.barType == QUICKSLOTBAR and settings.barMode == QUICKSLOT_MODE) or (barSettings.barType == EXTENSIONBAR and settings.barMode == EXTENSION_MODE) ) then
				self:SetOpacity( 0.25 );
				self:SetBackColor( Turbine.UI.Color(1,0,1,0) );
			else
				if ( barSettings.barType == QUICKSLOTBAR ) then
					self:SetOpacity( 0.5 );
					self:SetBackColor( Turbine.UI.Color(1,0.4,0.6,0.8) );
				else
					self:SetOpacity( 0.15 );
				end
			end
		end

		if ( barSettings.barType == EXTENSIONBAR and settings.barMode ~= NORMAL_MODE ) then
			self:SetBackColor( Turbine.UI.Color(1,1,1,0) );
		end
		self:SetVisible( true );
	else
		if ( self.faded ) then
			self:SetOpacity( barSettings.fadeOpacity );
		else
			self:SetOpacity( 1 );
		end
		if ( barSettings.useBackgroundColor == true ) then
			self:SetBackColor( Turbine.UI.Color( barSettings.opacity, barSettings.backgroundColorRed, barSettings.backgroundColorGreen, barSettings.backgroundColorBlue) );
			self:ClearTab( true );
		else
			self:SetBackColor( Turbine.UI.Color( 0, 0, 0, 0) );
			self:ClearTab( false );
		end
		if (barSettings.barType ~= EXTENSIONBAR) then
			self:RefreshKeys( false );
		else
			self:SetVisible( false );
		end
	end
	
	self.quickslotList:SetAllowDrop( not barSettings.locked );
	self.quickslotList:SetMaxItemsPerLine( barSettings.quickslotColumns );
	local showQuickslots = (settings.barMode ~= NORMAL_MODE) or barSettings.locked == false;
	local lockQuickslots = barSettings.locked and settings.barMode == NORMAL_MODE;
	self.quickslotList:Refresh( showQuickslots, lockQuickslots );

	self:SetBarSize();
end

function Bar:SetBarSize()
	self:SetSize( self.quickslotList:GetWidth(), self.quickslotList:GetHeight() );
end

function Bar:F12Pressed()
	self.f12HideBar = not self.f12HideBar;
end

function Bar:GetQuickslotList()
	return self.quickslotList;
end

function Bar:GetID()
	return self.id;
end