-- Created by NuclearTonic
-- If reusing this code, please keep the name of the original author listed
-- in respect for borrowing said authors code.
-- RESPECT!

import "Turbine";
import "Turbine.UI";
import "Tonic.Utils.Class";
import "Tonic.TonicBars.QuickslotBar";
import "Tonic.TonicBars.ExtensionBar";
import "Tonic.TonicBars.SettingsManager";

BarManager = class( Turbine.Object );

function BarManager:Constructor( sManager )
	self.working = false;
	self.theSettingsManager = sManager;
	Bars = { };		
	self:Construct( self.theSettingsManager:GetBars() );
end

function BarManager:RefreshBars()
	for key, value in pairs (Bars) do
		value:Refresh();
	end
end

function BarManager:Add( barType, cBarID, cQuickslotID )
	if ( self.working == false ) then
		self.working = true;
		local settings = self.theSettingsManager:GetSettings();
		local added = settings.nextBarId;
		Turbine.Shell.WriteLine( "Adding Bar: " .. settings.nextBarId	);
		if ( barType == QUICKSLOTBAR ) then
			tonic = QuickslotBar( settings.nextBarId, self.theSettingsManager, QUICKSLOTBAR );
		elseif ( barType == EXTENSIONBAR ) then
			tonic = ExtensionBar( settings.nextBarId, self.theSettingsManager );
			Bars[cBarID]:RegisterBarExtension( tonic, cQuickslotID, settings.nextBarId );
		end
		Bars[settings.nextBarId] = tonic;
		self.theSettingsManager:IncrementNextId();
		local barSettings = self.theSettingsManager:GetBarSettings( added );
		self.theSettingsManager:SetBarSettings( added, barSettings );
		self.working = false;
		return added;
	else
		Turbine.Shell.WriteLine( "Your actions are occuring too quickly, please slow down." );
		return nil;
	end
end

function BarManager:Remove( barid )
	eventManager:UnregisterForEvents( barid );

	Bars[barid]:SetVisible( false );
	Bars[barid]:SetParent( nil );
	Bars[barid]:ClearQuickslots( true );
	Bars[barid]:SetVisible( false );
	Bars[barid]:SetBackColor( Turbine.UI.Color( 0, 0, 0, 0) );
	Bars[barid] = nil;
	
	self.theSettingsManager:SetBarSettings( barid, nil);
end

function BarManager:Copy( barid )
	if ( self.working == false ) then
		self.working = true;
		local barsettings = self.theSettingsManager:GetBarSettings( barid );
		copyBarSettings = {};
		self.working = false;
		local added = self:Add();
		self.working = true;
		Bars[added]:SetVisible( true );
		theSettingsManager:deepcopy( barsettings, copyBarSettings );
		self.theSettingsManager:SetBarSettings( added, copyBarSettings );
		self.working = false;
		return added;
	else
		Turbine.Shell.WriteLine( "Your actions are occuring too quickly, please slow down. 3" );
		return nil;
	end
end

function BarManager:Reset( barid )
	if ( self.working == false ) then
		self.working = true;	
		self.theSettingsManager:SetBarSettings( barid, nil, false );
		local barsettings = self.theSettingsManager:GetBarSettings( barid );
		self.theSettingsManager:SetBarSettings( barid, barsettings );
		self.working = false;
	else
		Turbine.Shell.WriteLine( "Your actions are occuring too quickly, please slow down. 3" );
		return nil;
	end
end

function BarManager:Construct( storedBars )
	for key, value in pairs (storedBars) do
		if ( value.barType == QUICKSLOTBAR ) then
			tonic = QuickslotBar( tonumber(key), self.theSettingsManager, value.barType);
			
			Bars[tonumber(key)] = tonic;
		end
	end

	for key, value in pairs (storedBars) do
		if ( value.barType == EXTENSIONBAR ) then
			tonic = ExtensionBar( key, self.theSettingsManager);
			local attachedbarSettings = self.theSettingsManager:GetBarSettings( key );
			local bar = Bars[attachedbarSettings.connectionBarID];
			if ( bar ~= nil ) then
				bar:RegisterBarExtension( tonic, attachedbarSettings.connectionQuickslotID, key );
				Bars[tonumber(key)] = tonic;
			else
				self.theSettingsManager:SetBarSettings( key, nil);
				Turbine.Shell.WriteLine( "We found extension bar without a main bar. Deleting. Thank the community for the fix." );
			end
		end
	end
	
	for key, value in pairs (storedBars) do
		--Bars[tonumber(key)]:UpdateBarExtensions();
	end
end

function BarManager:GetBars()
	return Bars;
end

function BarManager:ShowExtensionBarMenu( barid )
	Bars[ barid ]:ShowBarMenu();
end

function BarManager:UpdateBarExtensions()
	for key, value in pairs (Bars) do
		local barsettings = self.theSettingsManager:GetBarSettings( key );
		if ( barsettings.barType == QUICKSLOTBAR and value ~= nil ) then
			Bars[ key ]:UpdateBarExtensions();
		end
	end
end

function BarManager:Alive( barid )
	if ( Bars[barid] == nil ) then
		return false;
	else
		return true;
	end
end