-- Created by NuclearTonic
-- The use of this code requires the permission of the author.
-- Permission can be atained by contacting NuclearTonic at: TonicBars@gmail.com
--
-- RESPECT!

import "Turbine";
import "Turbine.UI";
import "Turbine.UI.Lotro";
import "Tonic.Utils.Class";
import "Tonic.UI.CheckBox";
import "Tonic.UI.ComboBox";
import "Tonic.UI.AutoListBox";
import "Tonic.UI.MenuUtils";
import "Tonic.TonicBars.Extensions.TypeHelper";

buttonWidth = 85;
selectionWidth = 160;
selectionHeight = 20;
insideBoxXOffset = selectionWidth + 5;
insideBoxYOffset = startFromTop + 200;

ExtensionsMenu = class( Tonic.UI.AutoListBox );

function ExtensionsMenu:Constructor()
	Tonic.UI.AutoListBox.Constructor( self );
	
	self.utils = Tonic.UI.MenuUtils();

	self.upperBar = self.utils:AddAutoListBox( self, Turbine.UI.Orientation.Vertical, 0, 0, 0, 0 );
	self.utils:AddLabelBox( self.upperBar, LOCALESTRINGS.ExtensionsMenu[1], selectionWidth + 250, selectionHeight + 35 );
	
	self.utils:AddLabelBox( self.upperBar, LOCALESTRINGS.ExtensionsMenu[2], selectionWidth + 100, selectionHeight );
	
	self.barList = Tonic.UI.ComboBox();
	self.barList:SetSize( 200, 20 );
	self.barList:SetParent( self );
    self.barList.SelectedIndexChanged = function(sender, args)
		local settings = theSettingsManager:GetSettings();
		settings.selectedBar = tonumber(args.selection);
		self.scrollBox:SetVisible( true );
		menu:SetupMainMenuDisplay( EXTENSION_MODE );
		maitre_d:RefreshBars();
	end
	self.upperBar:AddItem( self.barList );
	self:AddItem( self.upperBar );
	
	self.scrollBox = self.utils:AddAutoListBox( self, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0 );

	self.sidebar = Turbine.UI.Lotro.ScrollBar();
	self.sidebar:SetParent( self.scrollBox );
	self.sidebar:SetOrientation( Turbine.UI.Orientation.Vertical );
	
	self:AddSettings();
	self:AddCommandsBar();
	
	self.scrollBox:AddItem( self.settingsBox );
	self.scrollBox:AddItem( self.sidebar );
	self.settingsBox:SetVerticalScrollBar( self.sidebar );
	self:AddItem( self.scrollBox );
	self.scrollBox:SetVisible( false );
	
	self.sidebar:SetSize ( 8, windowHeight - self.upperBar:GetHeight() - 105 );
	self.settingsBox:SetSize( self.settingsBox:GetWidth(), windowHeight - self.upperBar:GetHeight() - 105 );
end

function ExtensionsMenu:AddSettings()
	self.settingsBox = self.utils:AddAutoListBox( self, Turbine.UI.Orientation.Vertical, 0, 0, 0, 0 );

	self.utils:AddLabelBox( self.settingsBox, "", 50, selectionHeight );

	local box0 = self.utils:AddAutoListBox( self.settingsBox, Turbine.UI.Orientation.Horizontal, 0, selectionHeight + 20, 0, 0 );
	self.utils:AddLabelBox( box0, LOCALESTRINGS.ExtensionsMenu[3], 80, selectionHeight );
	self.barName = self.utils:AddTextBox(box0, "", selectionWidth, selectionHeight + 10 );
	local nameButton = Turbine.UI.Lotro.Button();
	nameButton:SetText( LOCALESTRINGS.ExtensionsMenu[4] );
	nameButton:SetSize( buttonWidth, selectionHeight );
	nameButton.MouseClick = function( sender, args )
		local selection = self.barList:GetSelection();
		local barSettings = theSettingsManager:GetBarSettings( selection );
		if ( barSettings.barName ~= self.barName:GetText() ) then
			barSettings.barName = self.barName:GetText();
			self:RefreshComboBox( self.barList:GetSelection() );
			theSettingsManager:SetBarSettings( selection, barSettings );
		end
	end
	box0:AddItem( nameButton );
	
	self.settingsBox:AddItem( box0 );

	self.utils:AddLabelBox( self.settingsBox, LOCALESTRINGS.ExtensionsMenu[5], selectionWidth + 200, selectionHeight + 5 );
	self.utils:AddLabelBox( self.settingsBox, LOCALESTRINGS.ExtensionsMenu[6], selectionWidth + 200, selectionHeight + 25 );
	
	self.typeList = Tonic.UI.ComboBox();
	self.typeList:SetSize( 200, 20 );
	self.typeList:SetParent( self.settingsBox );
	self.typeList:AddItem( LOCALESTRINGS.ExtensionTypes[1], 	HUNTER_TRAVEL_TYPE );
	self.typeList:AddItem( LOCALESTRINGS.ExtensionTypes[2], 	WARDEN_TRAVEL_TYPE );
	self.typeList:AddItem( LOCALESTRINGS.ExtensionTypes[3], 	REP_TRAVEL_TYPE );
	self.typeList:AddItem( LOCALESTRINGS.ExtensionTypes[4], 	HOUSING_TRAVEL_TYPE );
	self.typeList:AddItem( LOCALESTRINGS.ExtensionTypes[5], 	LM_COMBAT_PETS_TYPE );
	self.typeList:AddItem( LOCALESTRINGS.ExtensionTypes[6], 	LM_COSMETIC_PETS_TYPE );
	self.typeList:AddItem( LOCALESTRINGS.ExtensionTypes[7], 	CAPTAIN_PETS_TYPE );
	self.typeList:AddItem( LOCALESTRINGS.ExtensionTypes[8], 	HORSE1_TYPE );
	self.typeList:AddItem( LOCALESTRINGS.ExtensionTypes[9], 	HORSE2_TYPE );
	self.typeList:AddItem( LOCALESTRINGS.ExtensionTypes[10], 	PONY1_TYPE );
	self.typeList:AddItem( LOCALESTRINGS.ExtensionTypes[11], 	PONY2_TYPE );
	
	self.typeList:AddItem( LOCALESTRINGS.ExtensionTypes[12], 	INSTRUMENTS_TYPE );
	self.typeList:AddItem( LOCALESTRINGS.ExtensionTypes[13], 	MINI_DPS_TYPE );
	self.settingsBox:AddItem( self.typeList );
	
	self.utils:AddLabelBox( self.settingsBox, LOCALESTRINGS.ExtensionsMenu[7], selectionWidth + 100, selectionHeight + 5 );
	
	self.orientationList = Tonic.UI.ComboBox();
	self.orientationList:SetSize( 200, 20 );
	self.orientationList:SetParent( self.settingsBox );
	self.orientationList:AddItem( LOCALESTRINGS.Orientation[1], "Left" );
	self.orientationList:AddItem( LOCALESTRINGS.Orientation[2], "Right" );
	self.orientationList:AddItem( LOCALESTRINGS.Orientation[3], "Up" );
	self.orientationList:AddItem( LOCALESTRINGS.Orientation[4], "Down" );
	self.settingsBox:AddItem( self.orientationList );
	
	self.utils:AddLabelBox( self.settingsBox, LOCALESTRINGS.ExtensionsMenu[8], selectionWidth + 200, selectionHeight + 5 );
	
	self.mousedOverList = Tonic.UI.ComboBox();
	self.mousedOverList:SetSize( 200, 20 );
	self.mousedOverList:SetParent( self.settingsBox );
	self.mousedOverList:AddItem( LOCALESTRINGS.ExtensionRule[1], SHOW_EXTENSIONS );
	self.mousedOverList:AddItem( LOCALESTRINGS.ExtensionRule[2], ROLL_UP_SELECTION );
	self.mousedOverList:AddItem( LOCALESTRINGS.ExtensionRule[3], SELECT_RANDOM_SHORTCUT );
	self.mousedOverList:AddItem( LOCALESTRINGS.ExtensionRule[4], CYCLE_EXTENSIONS );
	self.settingsBox:AddItem( self.mousedOverList );
	
	self.utils:AddLabelBox( self.settingsBox, LOCALESTRINGS.ExtensionsMenu[9], selectionWidth + 200, selectionHeight + 5 );
	
	self.removalList = Tonic.UI.ComboBox();
	self.removalList:SetSize( 200, 20 );
	self.removalList:SetParent( self.settingsBox );
	self.removalList:AddItem( LOCALESTRINGS.ExtensionRemoval[1], 1 );
	self.removalList:AddItem( LOCALESTRINGS.ExtensionRemoval[2], 2 );
	self.settingsBox:AddItem( self.removalList );

--	self.settingsBox:AddItem( box1 );
	local box2a = self.utils:AddAutoListBox( self.settingsBox, Turbine.UI.Orientation.Vertical );
	local box2b = self.utils:AddAutoListBox( self.box2a, Turbine.UI.Orientation.Horizontal );

	self.utils:AddLabelBox( box2a, LOCALESTRINGS.ExtensionsMenu[10], selectionWidth + 100, selectionHeight + 5 );
	self.extSbNum = self.utils:AddLabelBox( box2b, "", 50, selectionHeight );
	self.extSb = self.utils:AddScrollBar( box2b, 1, 1, 50, 200, selectionHeight / 2 );

	box2a:AddItem( box2b );
	self.settingsBox:AddItem( box2a );
	local box4a = self.utils:AddAutoListBox( self.settingsBox, Turbine.UI.Orientation.Vertical );
	local box4b = self.utils:AddAutoListBox( self.box4a, Turbine.UI.Orientation.Horizontal );
	
	self.utils:AddLabelBox( box4a, LOCALESTRINGS.ExtensionsMenu[11], selectionWidth + 50, selectionHeight + 5 );
	self.extOpacityNum = self.utils:AddLabelBox( box4b, "", 50, selectionHeight );
	self.extOpacitySelection = self.utils:AddScrollBar( box4b, 0, 0, 100, 200, selectionHeight / 2 );

	box4a:AddItem( box4b );
	self.settingsBox:AddItem( box4a );
	local box5a = self.utils:AddAutoListBox( self.settingsBox, Turbine.UI.Orientation.Vertical );
	local box5b = self.utils:AddAutoListBox( self.box5a, Turbine.UI.Orientation.Horizontal );
	
	self.utils:AddLabelBox( box5a, LOCALESTRINGS.ExtensionsMenu[12], selectionWidth + 100, selectionHeight + 5 );
	self.extSpacingNum = self.utils:AddLabelBox( box5b, "", 50, selectionHeight );
	self.extSpacingSB = self.utils:AddScrollBar( box5b, 1, 0, 50, 200, selectionHeight / 2 );
	
	box5a:AddItem( box5b );
	self.settingsBox:AddItem( box5a );
	local box6a = self.utils:AddAutoListBox( self.settingsBox, Turbine.UI.Orientation.Vertical );
	local box6b = self.utils:AddAutoListBox( self.box6a, Turbine.UI.Orientation.Horizontal );

	self.utils:AddLabelBox( box6a, LOCALESTRINGS.ExtensionsMenu[13], selectionWidth + 50, selectionHeight + 5 );
	self.extSizeNum = self.utils:AddLabelBox( box6b, "", 50, selectionHeight );
	self.extSizeSB = self.utils:AddScrollBar( box6b, 16, 0, 20, 200, selectionHeight / 2 );
	
	box6a:AddItem( box6b );
	self.settingsBox:AddItem( box6a );
end

function ExtensionsMenu:DisplaySettings( showQuickslots )
	self.settingsBox:SetVisible( showQuickslots );
	
	local localBarSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );

	self.barName:SetText( localBarSettings.barName );

    self.typeList.SelectedIndexChanged = function(sender, args)
		local barSettings = nil;
		local hte = Tonic.TonicBars.Extensions.TypeHelper();
		local Bars = maitre_d.GetBars();
		if ( self.typeList:GetSelection() == HUNTER_TRAVEL_TYPE ) then
			hte:GetNewHunterTravelSettings( self.barList:GetSelection(), Bars[self.barList:GetSelection()]:GetQuickslotList() );
		elseif ( self.typeList:GetSelection() == WARDEN_TRAVEL_TYPE ) then
			hte:GetNewWardenTravelSettings( self.barList:GetSelection(), Bars[self.barList:GetSelection()]:GetQuickslotList() );
		elseif ( self.typeList:GetSelection() == HOUSING_TRAVEL_TYPE ) then
			hte:GetNewHousingTravelSettings( self.barList:GetSelection(), Bars[self.barList:GetSelection()]:GetQuickslotList() );
		elseif ( self.typeList:GetSelection() == LM_COMBAT_PETS_TYPE ) then
			hte:GetNewLMCombatPetsSettings( self.barList:GetSelection(), Bars[self.barList:GetSelection()]:GetQuickslotList() );
		elseif ( self.typeList:GetSelection() == LM_COSMETIC_PETS_TYPE ) then
			hte:GetNewLMCosmeticPetsSettings( self.barList:GetSelection(), Bars[self.barList:GetSelection()]:GetQuickslotList() );
		elseif ( self.typeList:GetSelection() == REP_TRAVEL_TYPE ) then
			hte:GetNewReputationTravelSettings( self.barList:GetSelection(), Bars[self.barList:GetSelection()]:GetQuickslotList() );
		elseif ( self.typeList:GetSelection() == HORSE1_TYPE ) then
			hte:GetNewHorsesSettings( self.barList:GetSelection(), Bars[self.barList:GetSelection()]:GetQuickslotList() );
		elseif ( self.typeList:GetSelection() == HORSE2_TYPE ) then
			hte:GetFesHorsesSettings( self.barList:GetSelection(), Bars[self.barList:GetSelection()]:GetQuickslotList() );
		elseif ( self.typeList:GetSelection() == PONY1_TYPE ) then
			hte:GetNewPoniesSettings( self.barList:GetSelection(), Bars[self.barList:GetSelection()]:GetQuickslotList() );
		elseif ( self.typeList:GetSelection() == PONY2_TYPE ) then
			hte:GetFesPoniesSettings( self.barList:GetSelection(), Bars[self.barList:GetSelection()]:GetQuickslotList() );
		elseif ( self.typeList:GetSelection() == INSTRUMENTS_TYPE ) then
			hte:GetNewMentorSettings( self.barList:GetSelection(), Bars[self.barList:GetSelection()]:GetQuickslotList() );
		elseif ( self.typeList:GetSelection() == MINI_DPS_TYPE ) then
			hte:GetNewMinstrelDpsSettings( self.barList:GetSelection(), Bars[self.barList:GetSelection()]:GetQuickslotList() );
		elseif ( self.typeList:GetSelection() == CAPTAIN_PETS_TYPE ) then
			hte:GetNewCaptainPetsSettings( self.barList:GetSelection(), Bars[self.barList:GetSelection()]:GetQuickslotList() );
		end
	end
	self.typeList:SetSelection( 0 );
	
    self.orientationList.SelectedIndexChanged = function(sender, args)
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.orientation = self.orientationList:GetSelection();
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.orientationList:SetSelection( localBarSettings.orientation );

    self.mousedOverList.SelectedIndexChanged = function(sender, args)
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.onMouseOver = self.mousedOverList:GetSelection();
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.mousedOverList:SetSelection( localBarSettings.onMouseOver );
	
    self.removalList.SelectedIndexChanged = function(sender, args)
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.barTermination = self.removalList:GetSelection();
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.removalList:SetSelection( localBarSettings.barTermination );
	
	self.extSb.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.quickslotCount = self.extSb:GetValue();
		self.extSbNum:SetText( self.extSb:GetValue() );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end	
	self.extSb:SetValue( localBarSettings.quickslotCount );

	self.extSbNum:SetText( localBarSettings.quickslotCount );

	self.extOpacitySelection.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.opacity = self.extOpacitySelection:GetValue() / 100;
		self.extOpacityNum:SetText( barSettings.opacity );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.extOpacitySelection:SetValue( localBarSettings.opacity * 100 );
	self.extSpacingSB.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.quickslotSpacing = self.extSpacingSB:GetValue();
		self.extSpacingNum:SetText( barSettings.quickslotSpacing );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.extSpacingSB:SetValue( localBarSettings.quickslotSpacing );
	self.extSizeSB.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.quickslotSize = self.extSizeSB:GetValue() + 16;
		self.extSizeNum:SetText( barSettings.quickslotSize );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.extSizeSB:SetValue( localBarSettings.quickslotSize - 16 );

	self.extOpacityNum:SetText( localBarSettings.opacity );
	self.extSpacingNum:SetText( localBarSettings.quickslotSpacing );
	self.extSizeNum:SetText( localBarSettings.quickslotSize );
end

function ExtensionsMenu:AddCommandsBar()
	self.extCommandsBox = Tonic.UI.AutoListBox();
	self.extCommandsBox:SetParent( self.settingsBox );
	self.extCommandsBox:SetBackColor( unselectedColor );
	self.extCommandsBox:SetOrientation( Turbine.UI.Orientation.Horizontal );
	
	local removeButton = Turbine.UI.Lotro.Button();
	removeButton:SetText( LOCALESTRINGS.ExtensionsMenu[14] );
	removeButton:SetSize( buttonWidth + 25, selectionHeight );

	removeButton.MouseClick = function( sender, args )
		maitre_d:Remove( tonumber( self.barList:GetSelection() ) );
		self.barList:RemoveItem( self.barList:GetSelection() );
	end
	self.extCommandsBox:AddItem( removeButton );

	self.settingsBox:AddItem( self.extCommandsBox );
end

function ExtensionsMenu:GetSelection()
	return self.barList:GetSelection();
end

function ExtensionsMenu:ClearSelection()
	local settings = theSettingsManager:GetSettings();
	settings.selectedBar = 0;
	self.settingsBox:SetVisible( false );
	self.barList:SetSelection();
end

function ExtensionsMenu:RefreshComboBox( barid )
	self.barList:Clear();
	for key, value in pairs (theSettingsManager:GetBars( EXTENSIONBAR )) do
		local found = false;
		for i = 1, self.barList:GetItemCount() do
			if ( self.barList:GetItem(i) == key) then
				found = true;
			end
		end
		if ( found == false ) then
			local text = key;
			local barSettings = theSettingsManager:GetBarSettings( key );
			if ( barSettings.barName ~= nil ) then
				text = barSettings.barName;
			end
			self.barList:AddItem( text, key );
		end
	end
	if ( barid ~= nil ) then
		self.barList:SetSelection( barid );
	end
end