-- Created by NuclearTonic
-- The use of this code requires the permission of the author.
-- Permission can be atained by contacting NuclearTonic at: TonicBars@gmail.com
--
-- RESPECT!

import "Turbine";
import "Turbine.UI";
import "Turbine.UI.Lotro";
import "Tonic.UI.AutoListBox";
import "Tonic.UI.MenuUtils";

buttonWidth = 85;
selectionWidth = 160;
selectionHeight = 20;
startFromTop = 39;
insideBoxXOffset = selectionWidth + 5;
insideBoxYOffset = startFromTop + 200;

QuickslotsMenu = class( Tonic.UI.AutoListBox );

function QuickslotsMenu:Constructor()
	Tonic.UI.AutoListBox.Constructor( self );
	
	self.utils = Tonic.UI.MenuUtils();
	
	self.upperBar = self.utils:AddAutoListBox( self, Turbine.UI.Orientation.Vertical, 0, 0, 0, 0 );
	self.utils:AddLabelBox( self.upperBar, LOCALESTRINGS.QuickslotsMenu[1], selectionWidth + 250, selectionHeight + 10 );
	
	local addButton = Turbine.UI.Lotro.Button();
	addButton:SetText( LOCALESTRINGS.QuickslotsMenu[2] );
	addButton:SetSize( buttonWidth, selectionHeight );
	addButton.MouseClick = function( sender, args )
		local barid = maitre_d:Add( QUICKSLOTBAR );
		self:RefreshComboBox( barid );
	end
	self.upperBar:AddItem( addButton );
	
	self.utils:AddLabelBox( self, LOCALESTRINGS.QuickslotsMenu[3], selectionWidth + 100, selectionHeight );
	
	self.barList = Tonic.UI.ComboBox();
	self.barList:SetSize( 200, 20 );
	self.barList:SetParent( self );
    self.barList.SelectedIndexChanged = function(sender, args)
		local settings = theSettingsManager:GetSettings();
		settings.selectedBar = tonumber(args.selection);
		self.scrollBox:SetVisible( true );
		menu:SetupMainMenuDisplay( QUICKSLOT_MODE );
		maitre_d:RefreshBars();
	end
	self.upperBar:AddItem( self.barList );
	
	self:AddSettings();
	self:AddItem( self.upperBar );
	self:AddTriggers();
	self:AddColorOptions();
	
	self.scrollBox = self.utils:AddAutoListBox( self, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0 );

	self.sidebar = Turbine.UI.Lotro.ScrollBar();
	self.sidebar:SetParent( self.scrollBox );
	self.sidebar:SetOrientation( Turbine.UI.Orientation.Vertical );
	
	self.scrollBox:AddItem( self.settingsBox );
	self.scrollBox:AddItem( self.sidebar );
	self.settingsBox:SetVerticalScrollBar( self.sidebar );
	self:AddItem( self.scrollBox );
	self.scrollBox:SetVisible( false );
		
	self.sidebar:SetSize ( 8, windowHeight - self.upperBar:GetHeight() - 105 );
	self.settingsBox:SetSize( self.settingsBox:GetWidth(), windowHeight - self.upperBar:GetHeight() - 105 );
end


function QuickslotsMenu:AddTriggers()
	local bgColor = Turbine.UI.Color(1,0.2,0.3,0.5);
	
	self.triggerDownWindow = self.utils:AddAutoListBox( self, Turbine.UI.Orientation.Vertical, 0, 0, 0, 0, bgColor );
    self.triggerDownWindow:SetZOrder(30);
    self.triggerDownWindow:SetVisible(false);
	self.triggerDownWindow:SetParent( self );

	self.triggerDownWindow.MouseLeave = function(sender, args)
		local x, y = self.triggerDownWindow:GetMousePosition();
		local xSize, ySize = self.triggerDownWindow:GetSize();
		if ( x < 0 or y < 0 or x > xSize or y > ySize ) then
			self.triggerDownWindow:SetVisible( false );
		end
	end
	
	self.triggerDownWindow.VisibleChanged = function(sender, args)
		if ( self.triggerDownWindow:IsVisible() == true ) then
			self.label1:SetVisible( false );
			self.label2:SetVisible( false );
			self.label3:SetVisible( false );
			self.label4:SetVisible( false );
		else
			self.label1:SetVisible( true );
			self.label2:SetVisible( true );
			self.label3:SetVisible( true );
			self.label4:SetVisible( true );			
		end
	end
	
	local containerbox = self.utils:AddAutoListBox( self.triggerDownWindow, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0, bgColor );
	local box0 = self.utils:AddAutoListBox( containerbox, Turbine.UI.Orientation.Vertical, 0, 0, 0, 0, bgColor );
	local box1 = self.utils:AddAutoListBox( self.triggerDownWindow, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0, bgColor );
	local box2 = self.utils:AddAutoListBox( self.triggerDownWindow, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0, bgColor );
	
	local dispLabel = self.utils:AddLabelBox( box0, LOCALESTRINGS.QuickslotsMenu[4], selectionWidth + 100, selectionHeight + 5, bgColor );
	
	self.combatBarCheckBox  = self.utils:AddCheckBox( box1, LOCALESTRINGS.QuickslotsDisplay[1], selectionWidth, selectionHeight, bgColor );
	self.outOfCombatBarCheckBox  = self.utils:AddCheckBox( box1, LOCALESTRINGS.QuickslotsDisplay[2], selectionWidth, selectionHeight, bgColor );
	self.altBarCheckBox     = self.utils:AddCheckBox( box1, LOCALESTRINGS.QuickslotsDisplay[3], selectionWidth, selectionHeight, bgColor );
	self.controlBarCheckBox = self.utils:AddCheckBox( box2, LOCALESTRINGS.QuickslotsDisplay[4], selectionWidth, selectionHeight, bgColor );
	self.shiftBarCheckBox   = self.utils:AddCheckBox( box2, LOCALESTRINGS.QuickslotsDisplay[5], selectionWidth, selectionHeight, bgColor );
	
	box0:AddItem( box1 );
	box0:AddItem( box2 );
	
	self.utils:AddLabelBox( box0, LOCALESTRINGS.QuickslotsMenu[4], selectionWidth + 100, selectionHeight + 5, bgColor );

	local events = eventManager:GetRegisteredEvents();
	self.eventCheckboxes = { };
	local count = 0;
	local box;
	for key, value in pairs (events.categories) do
		if ( count % 2 == 0 ) then
			box = self.utils:AddAutoListBox( self.triggerDownWindow, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0, bgColor );
		end
		self.eventCheckboxes[key] = self.utils:AddCheckBox( box, value.description, selectionWidth, selectionHeight, bgColor );
		self.eventCheckboxes[key].CheckedCallback = function( sender, args )
			local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
			if ( self.eventCheckboxes[key].IsChecked ) then
				if ( barSettings.events == nil ) then
					barSettings.events = { }; 
				end
				if ( barSettings.events.categories == nil ) then
					barSettings.events.categories = { };
				end
				barSettings.events.categories[key] = true;
			elseif ( barSettings.events ~= nil ) then
				barSettings.events.categories[key] = nil;
			end
			theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
		end
		if ( count % 2 == 0 ) then
			box0:AddItem( box );
		end
		count = count + 1;
	end
	count = 0;
	
	self.utils:AddLabelBox( box0, LOCALESTRINGS.QuickslotsMenu[5], selectionWidth + 200, selectionHeight + 5, bgColor );
	if ( events.classes ~= nil and events.classes[playerClass] ~= nil and events.classes[playerClass].effects ~= nil ) then
		for key, value in pairs (events.classes[playerClass].effects) do
			if ( count % 2 == 0 ) then
				box = self.utils:AddAutoListBox( self.triggerDownWindow, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0, bgColor );
			end
			self.eventCheckboxes[key] = self.utils:AddCheckBox( box, value.description, selectionWidth, selectionHeight, bgColor );
			self.eventCheckboxes[key].CheckedCallback = function( sender, args )
				local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
				if ( self.eventCheckboxes[key].IsChecked ) then
					if ( barSettings.events == nil ) then
						barSettings.events = { }; 
					end
					if ( barSettings.events.effects == nil ) then
						barSettings.events.effects = { };
					end
					barSettings.events.effects[key] = true;
				elseif ( barSettings.events ~= nil ) then
					barSettings.events.effects[key] = nil;
				end
				theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
			end
			if ( count % 2 == 0 ) then
				box0:AddItem( box );
			end
			count = count + 1;
		end
	end
	local blankLabel = self.utils:AddLabelBox( box0, "", selectionWidth + 100, selectionHeight, bgColor );
	
	local box6 = self.utils:AddAutoListBox( self.triggerDownWindow, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0, bgColor );
	self.healthTriggerCheckBox = self.utils:AddCheckBox( box0, LOCALESTRINGS.QuickslotsMenu[6], selectionWidth + 100, selectionHeight, bgColor );
	self.healthNum = self.utils:AddLabelBox( box6, "", 30, selectionHeight, bgColor );
	self.healthSB = self.utils:AddScrollBar( box6, 0, 0, 100, 200, selectionHeight / 2, bgColor );
	box0:AddItem( box6 );
	
	local box7 = self.utils:AddAutoListBox( self.triggerDownWindow, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0, bgColor );
	self.powerTriggerCheckBox = self.utils:AddCheckBox( box0, LOCALESTRINGS.QuickslotsMenu[7], selectionWidth + 100, selectionHeight, bgColor );
	self.powerNum = self.utils:AddLabelBox( box7, "", 30, selectionHeight, bgColor );
	self.powerSB = self.utils:AddScrollBar( box7, 0, 0, 100, 200, selectionHeight / 2, bgColor );
	box0:AddItem( box7 );
	
	local hideTriggerButton = Turbine.UI.Lotro.Button();
	hideTriggerButton:SetParent( self.triggerDownWindow );
	hideTriggerButton:SetText( LOCALESTRINGS.QuickslotsMenu[8] );
	hideTriggerButton:SetSize( buttonWidth + 100, selectionHeight );
	hideTriggerButton.MouseClick = function( sender, args )
		self.triggerDownWindow:SetVisible( false );
	end
	
	containerbox:AddItem( box0 );
	
	local sidebar = Turbine.UI.Lotro.ScrollBar();
	sidebar:SetParent( self.triggerDownWindow );
	sidebar:SetOrientation( Turbine.UI.Orientation.Vertical );

	containerbox:AddItem( sidebar );
	box0:SetVerticalScrollBar( sidebar );
	
	self.triggerDownWindow:AddItem( containerbox );
	sidebar:SetSize ( 8, 360 );
	box0:SetSize( self:GetWidth() - 5 - 8, 360 - hideTriggerButton:GetHeight() );
	self.triggerDownWindow:SetSize( self:GetWidth() - 5, 360 );
	hideTriggerButton:SetPosition( 0, self.triggerDownWindow:GetHeight() - selectionHeight );
end

function QuickslotsMenu:DisplayTriggers( showQuickslots )
	self.triggerDownWindow:SetVisible( showQuickslots );

	local localBarSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
	if ( localBarSettings.events == nil ) then
		localBarSettings.events = { };
	end

	self.combatBarCheckBox.CheckedCallback = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		if ( self.combatBarCheckBox.IsChecked ) then
			barSettings.events.displayInCombat = true;
		else
			barSettings.events.displayInCombat = nil;
		end
		self:ShouldCheckBeVisible( barSettings );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.combatBarCheckBox:SetChecked( localBarSettings.events.displayInCombat );
	self.outOfCombatBarCheckBox.CheckedCallback = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		if ( self.outOfCombatBarCheckBox.IsChecked ) then
			barSettings.events.displayNotInCombat = true;
		else
			barSettings.events.displayNotInCombat = nil;
		end
		self:ShouldCheckBeVisible( barSettings );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.outOfCombatBarCheckBox:SetChecked( localBarSettings.events.displayNotInCombat );
	self.altBarCheckBox.CheckedCallback = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		if ( self.altBarCheckBox.IsChecked ) then
			barSettings.events.isAlt = true;
		else
			barSettings.events.isAlt = nil;
		end
		self:ShouldCheckBeVisible( barSettings );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.altBarCheckBox:SetChecked( localBarSettings.events.isAlt );
	self.controlBarCheckBox.CheckedCallback = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		if ( self.controlBarCheckBox.IsChecked ) then
			barSettings.events.isControl = true;
		else
			barSettings.events.isControl = nil;
		end
		self:ShouldCheckBeVisible( barSettings );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.controlBarCheckBox:SetChecked( localBarSettings.events.isControl );
	self.shiftBarCheckBox.CheckedCallback = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		if ( self.shiftBarCheckBox.IsChecked ) then
			barSettings.events.isShift = true;
		else
			barSettings.events.isShift = nil;
		end
		self:ShouldCheckBeVisible( barSettings );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.shiftBarCheckBox:SetChecked( localBarSettings.events.isShift );

	if ( self.eventCheckboxes ~= nil ) then
		for key, value in pairs (self.eventCheckboxes) do
			local checked = false;
			if ( localBarSettings.events.categories ~= nil and localBarSettings.events.categories[key] ~= nil ) then
				checked = true;
			end
			if ( localBarSettings.events.effects ~= nil and localBarSettings.events.effects[key] ~= nil ) then
				checked = true;
			end
			value:SetChecked( checked );
		end
	end

	self.healthTriggerCheckBox.CheckedCallback = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		if ( self.healthTriggerCheckBox.IsChecked ) then
			barSettings.events.displayOnHealth = true;
		else
			barSettings.events.displayOnHealth = nil;
		end
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end	
	self.healthTriggerCheckBox:SetChecked( localBarSettings.events.displayOnHealth );
	
	self.healthSB.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.events.healthTrigger = self.healthSB:GetValue() / 100;
		self.healthNum:SetText( barSettings.events.healthTrigger * 100 );
		self:SetColors( barSettings );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.healthSB:SetValue( localBarSettings.events.healthTrigger * 100 );
	self.healthNum:SetText( localBarSettings.events.healthTrigger * 100 );

	self.powerTriggerCheckBox.CheckedCallback = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		if ( self.powerTriggerCheckBox.IsChecked ) then
			barSettings.events.displayOnPower = true;
		else
			barSettings.events.displayOnPower = nil;
		end
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end	
	self.powerTriggerCheckBox:SetChecked( localBarSettings.events.displayOnPower );

	self.powerSB.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.events.powerTrigger = self.powerSB:GetValue() / 100;
		self.powerNum:SetText( barSettings.events.powerTrigger * 100 );
		self:SetColors( barSettings );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.powerSB:SetValue( localBarSettings.events.powerTrigger * 100 );
	self.powerNum:SetText( localBarSettings.events.powerTrigger * 100 );
end

function QuickslotsMenu:AddColorOptions()
	local bgColor = Turbine.UI.Color(1,0.2,0.3,0.5);

	self.colorDownWindow = Turbine.UI.Control();
    self.colorDownWindow:SetZOrder(10);
    self.colorDownWindow:SetVisible(false);
	self.colorDownWindow:SetParent( self );
	self.colorDownWindow:SetBackColor( bgColor );
	
	self.colorDownWindow.MouseLeave = function(sender, args)
		local x, y = self.colorDownWindow:GetMousePosition();
		local xSize, ySize = self.colorDownWindow:GetSize();
		if ( x < 0 or y < 0 or x > xSize or y > ySize ) then
			self.colorDownWindow:SetVisible( false );
		end
	end
	
	self.colorDownWindow.VisibleChanged = function(sender, args)
		if ( self.colorDownWindow:IsVisible() == true ) then
			self.label1:SetVisible( false );
			self.label2:SetVisible( false );
			self.label3:SetVisible( false );
			self.label4:SetVisible( false );
		else
			self.label1:SetVisible( true );
			self.label2:SetVisible( true );
			self.label3:SetVisible( true );
			self.label4:SetVisible( true );			
		end
	end
	local box0 = self.utils:AddAutoListBox( self.colorDownWindow, Turbine.UI.Orientation.Vertical, 0, 0, 0, 0, bgColor );
	
	local box8a = self.utils:AddAutoListBox( self.colorDownWindow, Turbine.UI.Orientation.Vertical, 0, 0, 0, 0, bgColor );
	local box8b = self.utils:AddAutoListBox( self.box8a, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0, bgColor );
	local box8c = self.utils:AddAutoListBox( self.box8a, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0, bgColor );
	local box8d = self.utils:AddAutoListBox( self.box8a, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0, bgColor );
	local box8e = self.utils:AddAutoListBox( self.box8a, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0, bgColor );

	self.useBackgroundCheckBox  = self.utils:AddCheckBox( box8a, LOCALESTRINGS.QuickslotsMenu[9], selectionWidth + 150, selectionHeight, bgColor );

	local lb = self.utils:AddLabelBox( box8b, LOCALESTRINGS.QuickslotsMenu[10], 50, selectionHeight, bgColor );
	self.bgRNum = self.utils:AddLabelBox( box8b, "", 50, selectionHeight, bgColor );
	self.bgRSB = self.utils:AddScrollBar( box8b, 0, 0, 100, 200, selectionHeight / 2, bgColor );

	lb = self.utils:AddLabelBox( box8c, LOCALESTRINGS.QuickslotsMenu[11], 50, selectionHeight, bgColor );
	self.bgGNum = self.utils:AddLabelBox( box8c, "", 50, selectionHeight, bgColor );
	self.bgGSB = self.utils:AddScrollBar( box8c, 0, 0, 100, 200, selectionHeight / 2, bgColor );

	lb = self.utils:AddLabelBox( box8d, LOCALESTRINGS.QuickslotsMenu[12], 50, selectionHeight, bgColor );
	self.bgBNum = self.utils:AddLabelBox( box8d, "", 50, selectionHeight, bgColor );
	self.bgBSB = self.utils:AddScrollBar( box8d, 0, 0, 100, 200, selectionHeight / 2, bgColor );

	self.bgANum = self.utils:AddLabelBox( box8e, "", 50, selectionHeight, bgColor );
	self.bgASB = self.utils:AddScrollBar( box8e, 0, 0, 100, 200, selectionHeight / 2, bgColor );

	box8a:AddItem( box8b );
	box8a:AddItem( box8c );
	box8a:AddItem( box8d );
	lb = self.utils:AddLabelBox( box8a, LOCALESTRINGS.QuickslotsMenu[13], 100, selectionHeight, bgColor );
	box8a:AddItem( box8e );

	local box4a = self.utils:AddAutoListBox( self.settingsBox, Turbine.UI.Orientation.Vertical, 0, 0, 0, 0, bgColor );
	local box4b = self.utils:AddAutoListBox( self.box4a, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0, bgColor );

	self.fadeOpacityNum1 = self.utils:AddLabelBox( box4a, "", 50, selectionHeight, bgColor );
	self.fadeOpacityNum2 = self.utils:AddLabelBox( box4a, LOCALESTRINGS.QuickslotsMenu[14], 150, selectionHeight, bgColor );
	self.fadeOpacityNum3 = self.utils:AddLabelBox( box4b, "", 50, selectionHeight, bgColor );
	self.fadeOpacitySelection = self.utils:AddScrollBar( box4b, 0, 0, 100, 200, selectionHeight / 2, bgColor );
	
	box4a:AddItem( box4b );
	self.useFadingCheckBox  = self.utils:AddCheckBox( box4a, LOCALESTRINGS.QuickslotsMenu[15], selectionWidth + 200, selectionHeight, bgColor );
	
	box0:AddItem( box8a );
	box0:AddItem( box4a );

	local colorButton = Turbine.UI.Lotro.Button();
	colorButton:SetText( LOCALESTRINGS.QuickslotsMenu[16] );
	colorButton:SetSize( buttonWidth + 100, selectionHeight );
	colorButton.MouseClick = function( sender, args )
		self.colorDownWindow:SetVisible( false );
	end
	box0:AddItem( colorButton );
	
	self.colorDownWindow:SetSize( self.settingsBox:GetWidth(), box0:GetHeight() );
end

function QuickslotsMenu:DisplayColorOptions( showQuickslots )
	self.colorDownWindow:SetVisible( showQuickslots );

	local localBarSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
	
	self.useBackgroundCheckBox.CheckedCallback = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.useBackgroundColor = self.useBackgroundCheckBox.IsChecked;
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end	
	self.useBackgroundCheckBox:SetChecked( localBarSettings.useBackgroundColor );
	self.bgRSB.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.backgroundColorRed = self.bgRSB:GetValue() / 100;
		self.bgRNum:SetText( barSettings.backgroundColorRed );
		self:SetColors( barSettings );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.bgRSB:SetValue( localBarSettings.backgroundColorRed * 100 );
	self.bgGSB.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.backgroundColorGreen = self.bgGSB:GetValue() / 100;
		self.bgGNum:SetText( barSettings.backgroundColorGreen );
		self:SetColors( barSettings );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.bgGSB:SetValue( localBarSettings.backgroundColorGreen * 100 );
	self.bgBSB.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.backgroundColorBlue = self.bgBSB:GetValue() / 100;
		self.bgBNum:SetText( barSettings.backgroundColorBlue );
		self:SetColors( barSettings );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.bgBSB:SetValue( localBarSettings.backgroundColorBlue * 100 );
	self.bgASB.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.opacity = self.bgASB:GetValue() / 100;
		self.bgANum:SetText( barSettings.opacity );
		self:SetColors( barSettings );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.bgASB:SetValue( localBarSettings.opacity * 100 );

	
	self.fadeOpacitySelection.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.fadeOpacity = self.fadeOpacitySelection:GetValue() / 100;
		self.fadeOpacityNum3:SetText( barSettings.fadeOpacity );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.fadeOpacitySelection:SetValue( localBarSettings.fadeOpacity * 100 );
	self.useFadingCheckBox.CheckedCallback = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.useFading = self.useFadingCheckBox.IsChecked;
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end	
	self.useFadingCheckBox:SetChecked( localBarSettings.useFading );

	self.fadeOpacityNum3:SetText( localBarSettings.fadeOpacity );
	self.spacingNum:SetText( localBarSettings.quickslotSpacing );
	self.sizeNum:SetText( localBarSettings.quickslotSize );
		
	self.bgRNum:SetText( localBarSettings.backgroundColorRed );
	self.bgGNum:SetText( localBarSettings.backgroundColorGreen );
	self.bgBNum:SetText( localBarSettings.backgroundColorBlue );
	self.bgANum:SetText( localBarSettings.opacity );

	self:SetColors( localBarSettings );
end

function QuickslotsMenu:AddSettings()
	self.settingsBox = self.utils:AddAutoListBox( self.scrollBox, Turbine.UI.Orientation.Vertical, 0, 0, 0, 0 );

	self.utils:AddLabelBox( self.settingsBox, "", 50, selectionHeight );

	local box0 = self.utils:AddAutoListBox( self.settingsBox, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0 );
	self.utils:AddLabelBox( box0, LOCALESTRINGS.QuickslotsMenu[17], 80, selectionHeight );
	self.barName = self.utils:AddTextBox(box0, "", selectionWidth, selectionHeight + 10 );

	local nameButton = Turbine.UI.Lotro.Button();
	nameButton:SetText( LOCALESTRINGS.QuickslotsMenu[18] );
	nameButton:SetSize( buttonWidth, selectionHeight );
	nameButton.MouseClick = function( sender, args )
		local selection = self.barList:GetSelection();
		local barSettings = theSettingsManager:GetBarSettings( selection );
		barSettings.barName = self.barName:GetText();
		self:RefreshComboBox( self.barList:GetSelection() );
		theSettingsManager:SetBarSettings( selection, barSettings );
	end
	box0:AddItem( nameButton );
	
	self.settingsBox:AddItem( box0 );
	local box1 = self.utils:AddAutoListBox( self.settingsBox, Turbine.UI.Orientation.Horizontal );	
	self.barVisibleCheckBox = self.utils:AddCheckBox( box1, LOCALESTRINGS.QuickslotsMenu[19], selectionWidth, selectionHeight );
	self.barLockedCheckBox = self.utils:AddCheckBox( box1, LOCALESTRINGS.QuickslotsMenu[20], selectionWidth, selectionHeight );
	
	self.settingsBox:AddItem( box1 );
	local box2a = self.utils:AddAutoListBox( self.settingsBox, Turbine.UI.Orientation.Vertical );
	local box2b = self.utils:AddAutoListBox( self.box2a, Turbine.UI.Orientation.Horizontal );

	self.label1 = self.utils:AddLabelBox( box2a, LOCALESTRINGS.QuickslotsMenu[21], selectionWidth + 100, selectionHeight + 5 );
	self.sbNum = self.utils:AddLabelBox( box2b, "", 50, selectionHeight );
	self.sb = self.utils:AddScrollBar( box2b, 1, 1, 1000, 200, selectionHeight / 2 );

	box2a:AddItem( box2b );
	self.settingsBox:AddItem( box2a );
	local box3a = self.utils:AddAutoListBox( self.settingsBox, Turbine.UI.Orientation.Vertical );
	local box3b = self.utils:AddAutoListBox( self.box3a, Turbine.UI.Orientation.Horizontal );
	
	self.label2 = self.utils:AddLabelBox( box3a, LOCALESTRINGS.QuickslotsMenu[22], selectionWidth + 100, selectionHeight + 5 );
	self.sb2Num = self.utils:AddLabelBox( box3b, "", 50, selectionHeight );
	self.sb2 = self.utils:AddScrollBar( box3b, 1, 1, 50, 200, selectionHeight / 2 );

	box3a:AddItem( box3b );
	self.settingsBox:AddItem( box3a );
	local box5a = self.utils:AddAutoListBox( self.settingsBox, Turbine.UI.Orientation.Vertical );
	local box5b = self.utils:AddAutoListBox( self.box5a, Turbine.UI.Orientation.Horizontal );
	
	self.label3 = self.utils:AddLabelBox( box5a, LOCALESTRINGS.QuickslotsMenu[23], selectionWidth + 100, selectionHeight + 5 );
	self.spacingNum = self.utils:AddLabelBox( box5b, "", 50, selectionHeight );
	self.spacingSB = self.utils:AddScrollBar( box5b, 1, 0, 50, 200, selectionHeight / 2 );
	
	box5a:AddItem( box5b );
	self.settingsBox:AddItem( box5a );
	local box6a = self.utils:AddAutoListBox( self.settingsBox, Turbine.UI.Orientation.Vertical );
	local box6b = self.utils:AddAutoListBox( self.box6a, Turbine.UI.Orientation.Horizontal );

	self.label4 = self.utils:AddLabelBox( box6a, LOCALESTRINGS.QuickslotsMenu[24], selectionWidth + 50, selectionHeight + 5 );
	self.sizeNum = self.utils:AddLabelBox( box6b, "", 50, selectionHeight );
	self.sizeSB = self.utils:AddScrollBar( box6b, 16, 0, 20, 200, selectionHeight / 2 );
	
	box6a:AddItem( box6b );
	self.settingsBox:AddItem( box6a );
	
	self.triggerButton = Turbine.UI.Lotro.Button();
	self.triggerButton:SetText( LOCALESTRINGS.QuickslotsMenu[25] );
	self.triggerButton:SetSize( buttonWidth + 100, selectionHeight );
	self.triggerButton.MouseClick = function( sender, args )
		self.triggerDownWindow:SetPosition( self.triggerButton:GetLeft(), self.upperBar:GetHeight() + self.triggerButton:GetTop() - self.triggerDownWindow:GetHeight() + self.triggerButton:GetHeight() + 20 );
		self:DisplayTriggers( true );
	end
	self.settingsBox:AddItem( self.triggerButton );
	
	local colorButton = Turbine.UI.Lotro.Button();
	colorButton:SetText( LOCALESTRINGS.QuickslotsMenu[26] );
	colorButton:SetSize( buttonWidth + 100, selectionHeight );
	colorButton.MouseClick = function( sender, args )
		self.colorDownWindow:SetPosition( colorButton:GetLeft(), self.upperBar:GetHeight() + colorButton:GetTop() - self.colorDownWindow:GetHeight() + colorButton:GetHeight() + 20 );
		self:DisplayColorOptions( true );
	end
	self.settingsBox:AddItem( colorButton );
	
	self:AddCommandsBar();
end

function QuickslotsMenu:DisplaySettings( showQuickslots )
	self.scrollBox:SetVisible( showQuickslots );
	
	local localBarSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );

	self.barName.FocusLost = function(sender, args)
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.barName = self.barName:GetText();
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );		
	end
	self.barName:SetText( localBarSettings.barName );
	
	self.barVisibleCheckBox.CheckedCallback = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.visible = self.barVisibleCheckBox.IsChecked;
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.barVisibleCheckBox:SetChecked( localBarSettings.visible );
	self.barLockedCheckBox.CheckedCallback = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.locked = self.barLockedCheckBox.IsChecked;
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end	
	self.barLockedCheckBox:SetChecked( localBarSettings.locked );
	self.sb.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.quickslotCount = self.sb:GetValue();
		self.sbNum:SetText( self.sb:GetValue() );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end	
	self.sb:SetValue( localBarSettings.quickslotCount );
	self.sb2.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.quickslotColumns = self.sb2:GetValue();
		self.sb2Num:SetText( self.sb2:GetValue() );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end	
	self.sb2:SetValue( localBarSettings.quickslotColumns );

	self.sbNum:SetText( localBarSettings.quickslotCount );
	self.sb2Num:SetText( localBarSettings.quickslotColumns );

	self.spacingSB.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.quickslotSpacing = self.spacingSB:GetValue();
		self.spacingNum:SetText( barSettings.quickslotSpacing );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.spacingSB:SetValue( localBarSettings.quickslotSpacing );
	self.sizeSB.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.quickslotSize = self.sizeSB:GetValue() + 16;
		self.sizeNum:SetText( barSettings.quickslotSize );
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.sizeSB:SetValue( localBarSettings.quickslotSize - 16 );
end
function QuickslotsMenu:SetColors( barSettings )
	theColor = Turbine.UI.Color( barSettings.opacity, barSettings.backgroundColorRed, barSettings.backgroundColorGreen, barSettings.backgroundColorBlue )
	
	self.bgRNum:SetBackColor( theColor );
	self.bgGNum:SetBackColor( theColor );
	self.bgBNum:SetBackColor( theColor );
end

function QuickslotsMenu:AddCommandsBar()
	self.qsCommandsBox = Tonic.UI.AutoListBox();
	self.qsCommandsBox:SetParent( self.settingsBox );
	self.qsCommandsBox:SetBackColor( unselectedColor );
	self.qsCommandsBox:SetOrientation( Turbine.UI.Orientation.Horizontal );
	self.qsCommandsBox:SetVisible( true );

	local removeButton = Turbine.UI.Lotro.Button();
	removeButton:SetText( LOCALESTRINGS.QuickslotsMenu[27] );
	removeButton:SetSize( buttonWidth, selectionHeight );

	removeButton.MouseClick = function( sender, args )
		maitre_d:Remove( tonumber( self.barList:GetSelection() ) );
		self.barList:RemoveItem( self.barList:GetSelection() );
	end
	self.qsCommandsBox:AddItem( removeButton );
	
	local copyButton = Turbine.UI.Lotro.Button();
	copyButton:SetText( LOCALESTRINGS.QuickslotsMenu[28] );
	copyButton:SetSize( buttonWidth, selectionHeight );

	copyButton.MouseClick = function( sender, args )
		local barid = maitre_d:Copy( tonumber( self.barList:GetSelection() ) );
		self.barList:AddItem( barid, barid );
	end
	self.qsCommandsBox:AddItem( copyButton );
	
	local resetButton = Turbine.UI.Lotro.Button();
	resetButton:SetText( LOCALESTRINGS.QuickslotsMenu[29] );
	resetButton:SetSize( buttonWidth, selectionHeight );

	resetButton.MouseClick = function( sender, args )
		maitre_d:Reset( tonumber( self.barList:GetSelection() ) );
	end
	self.qsCommandsBox:AddItem( resetButton );
	
	self.settingsBox:AddItem( self.qsCommandsBox );
	
	self.utils:AddLabelBox( self.settingsBox, LOCALESTRINGS.QuickslotsMenu[30], 300, selectionHeight );
	self.utils:AddLabelBox( self.settingsBox, LOCALESTRINGS.QuickslotsMenu[31], 300, selectionHeight );
end

function QuickslotsMenu:GetSelection()
	return self.barList:GetSelection();
end

function QuickslotsMenu:ClearSelection()
	local settings = theSettingsManager:GetSettings();
	settings.selectedBar = 0;
	self.scrollBox:SetVisible( false );
	self.barList:SetSelection();
end

function QuickslotsMenu:ShouldCheckBeVisible( barSettings )

	if (barSettings.isCombatBar or barSettings.isAlt or barSettings.isControl or barSettings.isShift) then
		barSettings.visible = false;
		self.barVisibleCheckBox:SetChecked( false );
	else
		barSettings.visible = true;
		self.barVisibleCheckBox:SetChecked( true );
	end
end

function QuickslotsMenu:RefreshComboBox( barid )
	self.barList:Clear();
	for key, value in pairs (theSettingsManager:GetBars( QUICKSLOTBAR )) do
		local found = false;
		for i = 1, self.barList:GetItemCount() do
			if ( self.barList:GetItem(i) == key) then
				found = true;
			end
		end
		if ( found == false ) then
			local text = key;
			local barSettings = theSettingsManager:GetBarSettings( key );
			if ( barSettings.barName ~= nil ) then
				text = barSettings.barName;
			end
			self.barList:AddItem( text, key );
		end
	end
	if ( barid ~= nil ) then
		self.barList:SetSelection( barid );
	end
end