-- Created by NuclearTonic
-- The use of this code requires the permission of the author.
-- Permission can be atained by contacting NuclearTonic at: TonicBars@gmail.com
--
-- RESPECT!

import "Tonic.TonicBars.Bar";

QuickslotBar = class( Tonic.TonicBars.Bar );

function QuickslotBar:Constructor( barid, sManager, bartype )
	Tonic.TonicBars.Bar.Constructor( self, barid, sManager, bartype );
	
	local barSettings = self.theSettingsManager:GetBarSettings( self.id );
	if ( barSettings.barType ~= bartype ) then
		barSettings.barType = bartype;
		self.theSettingsManager:SetBarSettings( self.id, barSettings );
	end

	self.isVisible = true;

	self:UpdateBarExtensions();
	eventManager:RegisterForEvents( self, self.id );
end

function QuickslotBar:Create()
	local barSettings = self.theSettingsManager:GetBarSettings( self.id );
	
	self.quickslotList = QuickslotList( self.id, self, self.theSettingsManager );
	self.quickslotList = self:GetQuickslotList()
	self.quickslotList:SetParent( self );
	self.quickslotList:SetMaxItemsPerLine( barSettings.quickslotColumns );

	self.qsCreated = true;
	self:Refresh();
	
	if ( self.isModal ) then
		self.quickslotTab = Turbine.UI.ListBox();
		self.quickslotTab:SetParent( self );
		self.quickslotTab:SetSize( self:GetWidth() * 0.5, 10 );
		self.quickslotTab:SetPosition( self:GetWidth() - self.quickslotTab:GetWidth(), 0 );
		self.quickslotTab:SetBackColor( Turbine.UI.Color(0,0,0,0)  );
		
		self.quickslotList:SetPosition(0, self.quickslotTab:GetHeight() );
		self:SetBarSize();

		self.quickslotTab.MouseDown = function( sender, args )
			self:MouseDown(args);
		end
		self.quickslotTab.MouseMove = function( sender, args )
			self:MouseMove(args);
		end
		self.quickslotTab.MouseUp = function( sender, args )
			self:MouseUp(args);
		end

	else
		self.quickslotList:SetPosition(0, 0 );
	end
end

function QuickslotBar:ClearTab( cTab )
	if ( self.quickslotTab == nil ) then
		return;
	end
	local settings = self.theSettingsManager:GetSettings();
	if ( settings.barMode == NORMAL_MODE ) then
		self.clearTab = cTab;
		self.quickslotTab:SetSize( self:GetWidth(), 10 );
	else
		self.clearTab = false;
		self.quickslotTab:SetSize( self:GetWidth() * 0.5, 10 );
	end
end

function QuickslotBar:SetBarSize()
	if ( self.quickslotTab ~= nil and self.isModal ) then
		self:SetSize( self.quickslotList:GetWidth(), self.quickslotList:GetHeight() + self.quickslotTab:GetHeight() );
	else
		self:SetSize( self.quickslotList:GetWidth(), self.quickslotList:GetHeight() );
	end
end

function QuickslotBar:RefreshKeys(refresh)
	if ( refresh == nil or refresh ) then
		self:Refresh();
	end
	local settings = self.theSettingsManager:GetSettings();
	if ( self.isModal and self.quickslotTab ~= nil ) then
		self.quickslotTab:SetBackColor( Turbine.UI.Color(0,0,0,0)  );
		if ( self.clearTab ~= nil and self.clearTab and settings.barMode == NORMAL_MODE ) then
			self.quickslotTab:SetSize( self:GetWidth(), 10 );
		else
			self.quickslotTab:SetSize( self:GetWidth() * 0.5, 10 );
		end
		self.quickslotTab:SetPosition( self:GetWidth() - self.quickslotTab:GetWidth(), 0 );
	end
	self:SetBarSize();
end

function QuickslotBar:Refresh()
	Tonic.TonicBars.Bar.Refresh( self );
	if ( self.quickslotTab == nil ) then
		return;
	end
	local settings = self.theSettingsManager:GetSettings();
	local barSettings = self.theSettingsManager:GetBarSettings( self.id );

	if ( self.clearTab ~= nil and self.clearTab and settings.barMode == NORMAL_MODE ) then
		self.quickslotTab:SetSize( self:GetWidth(), 10 );
	else
		self.quickslotTab:SetSize( self:GetWidth() * 0.5, 10 );
	end
	self.quickslotTab:SetPosition( self:GetWidth() - self.quickslotTab:GetWidth(), 0 );
	eventManager:NotifyClients();
end

-- This function should ONLY be called by the Event Manager. Doing so in any other copacity
-- can and will cause issues with the visibility of the bars.
--
-- It is recommended to call: "eventManager:NotifyClients();" if needed.
function QuickslotBar:DetermineVisiblity( eventValue )
	local settings = self.theSettingsManager:GetSettings();
	local barSettings = self.theSettingsManager:GetBarSettings( self.id );

	if ( settings.barMode == NORMAL_MODE and barSettings.barType == QUICKSLOTBAR ) then
		local visible = false;
		if ( eventValue ~= nil and eventValue ) then
			visible = true;
		end
		if ( visible == false and self.isVisible == true ) then
			visible = barSettings.visible;
		end
	
		if ( self.f12HideBar ) then
			visible = false;
		end
		self:SetVisible( visible );
	end
end

function Bar:ClearQuickslots( removed )
	self.quickslotList:ClearQuickslots();
	if ( self.extensionBars ~= nil and removed ~= nil ) then
		for key, value in pairs (self.extensionBars) do
			maitre_d:Remove( self.extensionBars[ key ].bar:GetID() );
			self.extensionBars[ key ].bar = nil;
			self.extensionBars[ key ] = nil;
		end
	end
end

function QuickslotBar:UpdateBarExtensions()
	local barSettings = self.theSettingsManager:GetBarSettings( self.id );
	if ( self.extensionBars == nil ) then
		return;
	end

	for key, value in pairs ( self.extensionBars ) do
		local x, y = self.quickslotList:GetQuickslotLocation( value.quickslot );
		self.extensionBars[ key ].bar:Setup( x, y );
	end
end

function QuickslotBar:RegisterBarExtension( extBar, index, extensionBarID )
	local attachedbarSettings = self.theSettingsManager:GetBarSettings( extensionBarID );
	if ( attachedbarSettings.connectionQuickslotID ~= index or attachedbarSettings.connectionBarID ~= self.id ) then
		attachedbarSettings.connectionQuickslotID = index;
		attachedbarSettings.connectionBarID = self.id;
		self.theSettingsManager:SetBarSettings( extensionBarID, attachedbarSettings );
	end

	local barSettings = self.theSettingsManager:GetBarSettings( self.id );
	if ( self.nextExtension == nil ) then
		self.nextExtension = 1;
	end
	
	if ( barSettings.barType == QUICKSLOTBAR ) then
		if ( self.extensionBars == nil ) then
			self.extensionBars = {};
		end
		self.extensionBars[ self.nextExtension ] = {};
		self.extensionBars[ self.nextExtension ].bar = extBar;
		self.extensionBars[ self.nextExtension ].quickslot = index;
		self.extensionBars[ self.nextExtension ].cycleCount = 0;
		self.nextExtension = self.nextExtension + 1;
		
		self.quickslotList:SetupExtensionSlot( self.extensionBars, index );
	else
		Turbine.Shell.WriteLine( "You can not add extensions to an extension slot. Please choose a green bar." );
	end
end